function [nstates, Qav, Qre, pi0] = CTMC_CR(nm,n,lambdaB,lambdaR,muB,muR)
%CTMC_CR infinitesimal generator matrix and initial probability vector
% of the Component Redundancy (CR) CMTC
%   nm       : number of hot standy (n+m>=n+1)
%   n       : number of required rectifiers or batteries to address load
%   lambdaB : battery failure rate
%   lambdaR : rectifier failure rate
%   muB     : battery recovery rate
%   muR     : rectifier recovery rate

nstates = nm-n+2;% number of states only considering batteries

% define batteries' behavior
Rre = diag(lambdaB*[nm:-1:n],1);
Rre(2:end-1,1) = muB;

% % Plotting reliability model
% D= digraph(Rre);
% Plot = plot(D);
% highlight(Plot,nstates,'NodeColor','r');
% highlight(Plot,'Edges',inedges(D,nstates)','EdgeColor','r');

Rav = Rre;
Rav(end,1) = muB;

Qav = Rav - diag(Rav*ones(nstates,1));
Qre = Rre - diag(Rre*ones(nstates,1));

pi0 = zeros(1,nstates);
pi0(1) = 1;

end